#!/usr/bin/python
import sys
import getopt
import os
import time
import json
import re
from e3dc import E3DC
import socket  
import datetime
import argparse
import paho.mqtt.client as mqtt
import sys

dir_main = '/opt/'
dir_main2 = 'loxberry/'
dir_conf = 'config/plugins/e3dc/'
dir_log = 'log/plugins/e3dc/'

s = os.popen(". " + dir_main + dir_main2 + dir_conf + "e3dc.cfg && set").read()
env_vars = {x[:x.find("=")]:x[x.find("=")+2:-1] for x in s.split("\n")[:-1]}

TCP_IP = env_vars['E3DC_IP']
USERNAME = env_vars['E3DC_USER']
PASS = env_vars['E3DC_PASS']
KEY = env_vars['E3DC_KEY']
DEBUG = (int(env_vars['E3DC_DEBUG']))
mqtt_username = env_vars['MQTT_USER']
mqtt_password = env_vars['MQTT_PASS']
host = env_vars['MQTT_HOST']
port = (int(env_vars['MQTT_PORT']))

def on_disconnect(client, userdata, rc):
    if rc != 0:
        print("Unexpected MQTT disconnection. Will auto-reconnect")
        mqttc.connect(host, port, 60)
        print("Reconnecting to "+host+" port: "+str(port))

def on_connect(mqttc, obj, flags, rc):
        print("connect rc: " + str(rc))

parser = argparse.ArgumentParser(description='Description of your program')
parser.add_argument('-d','--do', help='Description for foo argument', required=True)
parser.add_argument('-v1','--val1', help='Description for bar argument', required=False)
parser.add_argument('-v2','--val2', help='Description for bar argument', required=False)
parser.add_argument('-v3','--val3', help='Description for bar argument', required=False)
parser.add_argument('-v4','--val4', help='Description for bar argument', required=False)
args = vars(parser.parse_args())

mqttc = mqtt.Client()
mqttc.username_pw_set(mqtt_username, mqtt_password)
mqttc.on_connect = on_connect
#print("Connecting to "+host+" port: "+str(port))
mqttc.connect(host, port, 60)

e3dc = E3DC(E3DC.CONNECT_LOCAL, username=USERNAME, password=PASS, ipAddress = TCP_IP, key = KEY)
    
if args['do'] == 'getPowerSettings':
    res=(e3dc.get_power_settings()) 
    result_mqtt = json.dumps(res)
    topic = 'e3dc/getpowersettings'
    mqttc.on_disconnect = on_disconnect
    infot = mqttc.publish(topic, result_mqtt , qos=0)
    
    
    
if args['do'] == 'getManualCharge':
    res=(e3dc.get_mc()) 
    result_mqtt = json.dumps(res)
    print(result_mqtt)
    topic = 'e3dc/getmanualcharge'
    mqttc.on_disconnect = on_disconnect
    infot = mqttc.publish(topic, result_mqtt , qos=0)
    
    
if args['do'] == 'setManualCharge':
    res=(e3dc.set_mc()) 
    result_mqtt = json.dumps(res)
    print(result_mqtt)
    topic = 'e3dc/setmanualcharge'
    mqttc.on_disconnect = on_disconnect
    infot = mqttc.publish(topic, result_mqtt , qos=0)    
    
    
if args['do'] == 'getPowerData':
    res=(e3dc.get_power_data()) 
    result_mqtt = json.dumps(res) 
    topic = 'e3dc/powerdata'
    mqttc.on_disconnect = on_disconnect
    infot = mqttc.publish(topic, result_mqtt , qos=0)
    
if args['do'] == 'getPowerMeterData':
    res=(e3dc.get_powermeter_data(pmIndex=(int(args['val1'])), keepAlive=False)) 
    result_mqtt = json.dumps(res) 
    topic = 'e3dc/powerdata'
    mqttc.on_disconnect = on_disconnect
    infot = mqttc.publish(topic, result_mqtt , qos=0)    
    
if args['do'] == 'getBatteryData':
    res=(e3dc.get_batteries_data())
    result_mqtt = json.dumps(res) 
    result_mqtt = result_mqtt.lstrip("[").rstrip("]")    
    topic = 'e3dc/batterydata'
    mqttc.on_disconnect = on_disconnect
    infot = mqttc.publish(topic, result_mqtt , qos=0)

if args['do'] == 'getSystemInfo':
    res=(e3dc.get_system_info())
    result_mqtt = json.dumps(res)   
    topic = 'e3dc/systeminfo'
    mqttc.on_disconnect = on_disconnect
    infot = mqttc.publish(topic, result_mqtt , qos=0)

if args['do'] == 'getPviData':
    res=(e3dc.get_pvi_data(pviIndex=0, strings=[0,1], phases=[0,1,2], keepAlive=False))
    result_mqtt = json.dumps(res)
    result_mqtt = result_mqtt.lstrip("[").rstrip("]")
    topic = 'e3dc/pvidata'
    mqttc.on_disconnect = on_disconnect
    infot = mqttc.publish(topic, result_mqtt , qos=0)

if args['do'] == 'getIdlePeriods':
    res=(e3dc.get_idle_periods())
    result_mqtt = json.dumps(res)
    
if args['do'] == 'getPowerDataExt':
    res=(e3dc.get_power_data_ext())
    result_mqtt = json.dumps(res)    
    topic = 'e3dc/powerdataext'
    mqttc.on_disconnect = on_disconnect
    infot = mqttc.publish(topic, result_mqtt , qos=0)
    
if args['do'] == 'getEPSettings':
    res=(e3dc.get_ep_settings())
    result_mqtt = json.dumps(res)   
    topic = 'e3dc/ep'
    mqttc.on_disconnect = on_disconnect
    infot = mqttc.publish(topic, result_mqtt , qos=0)    

if args['do'] == 'getDCDC':
    res0=(e3dc.get_dcdc_data(dcdcIndex=0, keepAlive=False))
    res1=(e3dc.get_dcdc_data(dcdcIndex=1, keepAlive=False))
    result_mqtt0 = json.dumps(res0)  
    result_mqtt1 = json.dumps(res1)
    result_mqtt = result_mqtt0 + result_mqtt1
    topic = 'e3dc/dcdc/0'
    mqttc.on_disconnect = on_disconnect
    infot = mqttc.publish(topic, result_mqtt0 , qos=0) 
    time.sleep(0.3)
    topic = 'e3dc/dcdc/1'
    infot = mqttc.publish(topic, result_mqtt1 , qos=0) 
    
if args['do'] == 'getEPR':
    res=(e3dc.get_epr())
    result_mqtt = json.dumps(res)   
    topic = 'e3dc/epr/0'
    mqttc.on_disconnect = on_disconnect
    infot = mqttc.publish(topic, result_mqtt , qos=0)       

if args['do'] == 'setEPR':
    res=(e3dc.set_epr(ep_reserve=(int(args['val1'])), keepAlive = False))
    result_mqtt = json.dumps(res)
    
if args['do'] == 'setPowersave':
    res=(e3dc.set_powersave((int(args['val1'])), keepAlive = False))
    result_mqtt = json.dumps(res)    

if args['do'] == 'setWeatherRegulatedCharge':
    res=(e3dc.set_weather_regulated_charge((int(args['val1'])), keepAlive = False))
    result_mqtt = json.dumps(res)
    
if args['do'] == 'setWeatherForecastMode':
    res=(e3dc.set_weather_forecast_mode((int(args['val1'])), keepAlive = False))
    result_mqtt = json.dumps(res)    

if args['do'] == 'setPowerLimits':
    res=(e3dc.set_power_limits((int(args['val1'])), max_charge=(int(args['val2'])), max_discharge=(int(args['val3'])), discharge_start=(int(args['val4'])), keepAlive = False))
    result_mqtt = json.dumps(res)


if args['do'] == 'setIdleTimeFull':   
    now = datetime.datetime.now()
    day = datetime.datetime.today().weekday()
    day = str(day)
    hours =   str(0)
    minutes = str(0)
    
    if (int(args['val1'])) == 0:
        todo = 'idleCharge'
        hours = '0'
        minutes = '0'
    elif (int(args['val1'])) == 1:
        todo = 'idleDischarge'
    
    if (int(args['val2'])) == 0:
        active = 'false'
        hours = '0'
        minutes = '0'
    elif (int(args['val2'])) == 1:
        active = 'true'
    
    for day in range(7):
        day_c = str(day)
        idlePeriods = '{"' + todo + '":[{"day":' + day_c + ',"start":[' + hours + ',' + minutes + '],"end":[23,59],"active":' + active + '}]}'
        
        idlePeriods1 = json.loads(idlePeriods)
        res = (e3dc.set_idle_periods(idlePeriods1, keepAlive = False))


if args['do'] == 'setIdleTime':   
    now = datetime.datetime.now()
    day = datetime.datetime.today().weekday()
    day = str(day)
    hours =   str(now.hour)
    minutes = now.minute - 2
    minutes = str(minutes)
    
    if (int(args['val1'])) == 0:
        todo = 'idleCharge'
        hours = '0'
        minutes = '0'
    elif (int(args['val1'])) == 1:
        todo = 'idleDischarge'
    
    if (int(args['val2'])) == 0:
        active = 'false'
        hours = '0'
        minutes = '0'
    elif (int(args['val2'])) == 1:
        active = 'true'

    idlePeriods = '{"' + todo + '":[{"day":' + day + ',"start":[' + hours + ',' + minutes + '],"end":[23,59],"active":' + active + '}]}'
    idlePeriods1 = json.loads(idlePeriods)
    res = (e3dc.set_idle_periods(idlePeriods1, keepAlive = False))
if result_mqtt != "":
    print(result_mqtt) 
    
if DEBUG == 1:
    result = json.dumps(res)
    debug = '\n\n' + datetime.datetime.now().strftime("%d/%m/%Y-%H:%M:%S") + ' DEBUG:\n' + args['do'] + '\n' + result_mqtt
    file_object = open(dir_main + dir_main2 + dir_log + 'e3dc.log', 'a')
    file_object.write(debug)
    file_object.close()

mqttc.disconnect()
sys.stderr = open(dir_main + dir_main2 + dir_log + 'e3dc_error.log', 'w')   
