#!/usr/bin/python
import sys
import getopt
import os
import time
import json
import re
import requests
from e3dc import E3DC
import socket  
import datetime 
from datetime import date
import paho.mqtt.client as mqtt
import sys

dir_main = '/opt/'
dir_main2 = 'loxberry/'
dir_conf = 'config/plugins/e3dc/'
dir_log = 'log/plugins/e3dc/'

s = os.popen(". " + dir_main + dir_main2 + dir_conf + "e3dc.cfg && set").read()
env_vars = {x[:x.find("=")]:x[x.find("=")+2:-1] for x in s.split("\n")[:-1]}

TCP_IP = env_vars['E3DC_IP']
USERNAME = env_vars['E3DC_USER']
PASS = env_vars['E3DC_PASS']
KEY = env_vars['E3DC_KEY']
DEBUG = (int(env_vars['E3DC_DEBUG']))
mqtt_username = env_vars['MQTT_USER']
mqtt_password = env_vars['MQTT_PASS']
host = env_vars['MQTT_HOST']
port = (int(env_vars['MQTT_PORT']))

def on_disconnect(client, userdata, rc):
    if rc != 0:
        print("Unexpected MQTT disconnection. Will auto-reconnect")
        mqttc.connect(host, port, 60)
        print("Reconnecting to "+host+" port: "+str(port))

def on_connect(mqttc, obj, flags, rc):
    print("connect rc: " + str(rc))


if len(sys.argv) < 3:
   print("Arguments Missing")
   exit()
   
day = date.today().day
month = date.today().month
year = date.today().year
prefix='unkown'

param_1= sys.argv[1]
param_2= sys.argv[2] 

mqttc = mqtt.Client()
mqttc.username_pw_set(mqtt_username, mqtt_password)
mqttc.on_connect = on_connect
#print("Connecting to "+host+" port: "+str(port))
mqttc.connect(host, port, 60)

if param_1 == 'YEAR' and param_2 == 'NOW':
    day = 1
    month = 1
    year = date.today().year
    prefix='thisyear'
    
if param_1 == 'MONTH' and param_2 == 'NOW':
    day = 1
    month = date.today().month
    year = date.today().year
    prefix='thismonth'

if param_1 == 'DAY' and param_2 == 'NOW':
    day = date.today().day
    month = date.today().month
    year = date.today().year 
    prefix='today'

if param_1 == 'YEAR' and param_2 == 'LAST':
    day = 1
    month = 1
    year = (date.today().year -1)
    prefix='lastyear'
    
if param_1 == 'MONTH' and param_2 == 'LAST':
    day = 1
    month = (date.today().month -1)
    year = (date.today().year)
    if month < 1:
        month = 12
        year = (date.today().year -1) 
    prefix='lastmonth'
    print (month)
    print (year)
    
if param_1 == 'DAY' and param_2 == 'LAST':
    xx = datetime.date.today() - datetime.timedelta(days=1)
    year = xx.year
    month = xx.month
    day = xx.day
    prefix='yesterday'
   
e3dc = E3DC(E3DC.CONNECT_LOCAL, username=USERNAME, password=PASS, ipAddress = TCP_IP, key = KEY)
res=(e3dc.get_db_data(startDate=datetime.date(year, month, day), timespan=param_1,  keepAlive=False )) 
result_mqtt = json.dumps(res)
result_mqtt = result_mqtt.replace("_", "-")
mqtt_ed = json.loads(result_mqtt)
bat_power_in_kwh = (round(mqtt_ed['bat-power-in'] / 1000 , 2))
bat_power_out_kwh = (round(mqtt_ed['bat-power-out'] / 1000 , 2))
solarProduction_kwh = (round(mqtt_ed['solarProduction'] / 1000 , 2))
grid_power_in_kwh = (round(mqtt_ed['grid-power-in'] / 1000 , 2))
grid_power_out_kwh    = (round(mqtt_ed['grid-power-out'] / 1000 , 2))
consumption_kwh = (round(mqtt_ed['consumption'] / 1000 , 2))
pm_0_kwh = (round(mqtt_ed['powermeter-0'] / 1000 , 2))
pm_1_kwh = (round(mqtt_ed['powermeter-1'] / 1000 , 2))
mqtt_new_val = {"bat-power-in-kwh":bat_power_in_kwh, "bat-power-out-kwh":bat_power_out_kwh, "solarProduction-kwh":solarProduction_kwh , "grid-power-in-kwh":grid_power_in_kwh, "grid-power-out-kwh":grid_power_out_kwh, "consumption-kwh":consumption_kwh, "powermeter-0-kwh":pm_0_kwh, "powermeter-1-kwh":pm_1_kwh,}
mqtt_ed.update(mqtt_new_val)
result_mqtt= (json.dumps(mqtt_ed))
print (result_mqtt)
topic = 'e3dc/db/' + prefix
mqttc.on_disconnect = on_disconnect
infot = mqttc.publish(topic, result_mqtt , qos=0)

if DEBUG == 1:
    result = json.dumps(res)
    debug = '\n\n' + datetime.datetime.now().strftime("%d/%m/%Y-%H:%M:%S") + ' DEBUG:\n' + param_1 + ' ' + param_2 + '\n' + result_mqtt
    file_object = open(dir_main + dir_main2 + dir_log + 'e3dc_db.log', 'a')
    file_object.write(debug)
    file_object.close()

mqttc.disconnect()    
sys.stderr = open(dir_main + dir_main2 + dir_log + 'e3dc_error.log', 'w')

#result = json.loads(result)
#udp_str="e3dc.%s.bat_power_in=%.2f e3dc.%s.bat_power_out=%.2f e3dc.%s.solarProduction=%.2f e3dc.%s.grid_power_in=%.2f e3dc.%s.grid_power_out=%.2f e3dc.%s.consumption=%.2f e3dc.%s.stateOfCharge=%.2f e3dc.%s.consumed_production=%.2f e3dc.%s.autarky=%.2f" % (prefix, (result['bat_power_in'] / 1000), prefix, (result['bat_power_out'] / 1000), prefix, (result['solarProduction'] / 1000), prefix, (result['grid_power_in'] / 1000), prefix, (result['grid_power_out'] / 1000), prefix, (result['consumption'] / 1000), prefix, result['stateOfCharge'], prefix, result['consumed_production'], prefix, result['autarky'])
#clientSock = socket.socket(socket.AF_INET, socket.SOCK_DGRAM)
#clientSock.sendto(udp_str.encode(), (UDP_IP_ADDRESS, UDP_PORT_NO))


