#!/bin/bash

# Shell script which is executed by bash *AFTER* complete installation is done
# (*AFTER* postinstall and *AFTER* postupdate). Use with caution and remember,
# that all systems may be different!
#
# Exit code must be 0 if executed successfull. 
# Exit code 1 gives a warning but continues installation.
# Exit code 2 cancels installation.
#
# !!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
# Will be executed as user "root".
# !!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
#
# You can use all vars from /etc/environment in this script.
#
# We add 5 additional arguments when executing this script:
# command <TEMPFOLDER> <NAME> <FOLDER> <VERSION> <BASEFOLDER>
#
# For logging, print to STDOUT. You can use the following tags for showing
# different colorized information during plugin installation:
#
# <OK> This was ok!"
# <INFO> This is just for your information."
# <WARNING> This is a warning!"
# <ERROR> This is an error!"
# <FAIL> This is a fail!"

# To use important variables from command line use the following code:
COMMAND=$0    # Zero argument is shell command
PTEMPDIR=$1   # First argument is temp folder during install
PSHNAME=$2    # Second argument is Plugin-Name for scipts etc.
PDIR=$3       # Third argument is Plugin installation folder
PVERSION=$4   # Forth argument is Plugin version
#LBHOMEDIR=$5 # Comes from /etc/environment now. Fifth argument is
              # Base folder of LoxBerry
PTEMPPATH=$6  # Sixth argument is full temp path during install (see also $1)

# Combine them with /etc/environment
PCGI=$LBPCGI/$PDIR
PHTML=$LBPHTML/$PDIR
PTEMPL=$LBPTEMPL/$PDIR
PDATA=$LBPDATA/$PDIR
PLOG=$LBPLOG/$PDIR # Note! This is stored on a Ramdisk now!
PCONFIG=$LBPCONFIG/$PDIR
PSBIN=$LBPSBIN/$PDIR
PBIN=$LBPBIN/$PDIR

echo -n "<INFO> Current working folder is: "
pwd
echo "<INFO> Command is: $COMMAND"
echo "<INFO> Temporary folder is: $PTEMPDIR"
echo "<INFO> (Short) Name is: $PSHNAME"
echo "<INFO> Installation folder is: $PDIR"
echo "<INFO> Plugin version is: $PVERSION"
echo "<INFO> Plugin CGI folder is: $PCGI"
echo "<INFO> Plugin HTML folder is: $PHTML"
echo "<INFO> Plugin Template folder is: $PTEMPL"
echo "<INFO> Plugin Data folder is: $PDATA"
echo "<INFO> Plugin Log folder (on RAMDISK!) is: $PLOG"
echo "<INFO> Plugin CONFIG folder is: $PCONFIG"

echo "<INFO> Install E3DC Files"

chmod 0755 $PBIN/*.*
pip3 install setuptools
pip3 install wheel
pip3 install python-dateutil
pip3 install requests
pip3 install websocket
pip3 install tzlocal
pip3 install datetime
pip3 install py3rijndael
pip3 install paho-mqtt==1.6.1
pip3 install pye3dc


echo "<INFO> Updating systemd service config"
serv_files="/etc/systemd/system/e3dc_current.service"
echo "[Unit]" > $serv_files
echo "Description=E3DC Current" >> $serv_files
echo "Requires=network.target" >> $serv_files
echo "After=loxberry.service" >> $serv_files
echo "" >> $serv_files
echo "[Service]" >> $serv_files
echo "Type=idle" >> $serv_files
echo "ExecStart=python3 "$PBIN"/current.py" >> $serv_files
echo "Environment="TERM=dumb"" >> $serv_files
echo "Restart=on-failure" >> $serv_files
echo "RestartSec=300" >> $serv_files
echo "StandardOutput=journal" >> $serv_files
echo "StandardError=journal" >> $serv_files
echo "" >> $serv_files
echo "[Install]" >> $serv_files
echo "WantedBy=multi-user.target" >> $serv_files
echo "<INFO> Enable systemd Service"
systemctl enable e3dc_current.service
echo "<INFO> Reloading systemd config"
systemctl daemon-reload
systemctl restart e3dc_current


filename=$PCONFIG"/e3dc.cfg"
check=$(grep -i "E3DC_DCDC" $filename | wc -l)
if [ "$check" -lt "1" ]; then
echo "" >> $filename
echo "E3DC_DCDC=\"0\"" >> $filename
fi
# Exit with Status 0
exit 0

